==> huaweicloudsdkdataartsstudio-3.1.71-py2.py3-none-any.whl: huaweicloudsdkdataartsstudio/v1/model/batch_delete_security_permission_set_members_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchDeleteSecurityPermissionSetMembersRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'permission_set_id': 'str',
        'workspace': 'str',
        'body': 'BatchDeleteBaseDTO'
    }

    attribute_map = {
        'permission_set_id': 'permission_set_id',
        'workspace': 'workspace',
        'body': 'body'
    }

    def __init__(self, permission_set_id=None, workspace=None, body=None):
        """BatchDeleteSecurityPermissionSetMembersRequest

        The model defined in huaweicloud sdk

        :param permission_set_id: 权限集id
        :type permission_set_id: str
        :param workspace: workspace 信息
        :type workspace: str
        :param body: Body of the BatchDeleteSecurityPermissionSetMembersRequest
        :type body: :class:`huaweicloudsdkdataartsstudio.v1.BatchDeleteBaseDTO`
        """
        
        

        self._permission_set_id = None
        self._workspace = None
        self._body = None
        self.discriminator = None

        self.permission_set_id = permission_set_id
        self.workspace = workspace
        if body is not None:
            self.body = body

    @property
    def permission_set_id(self):
        """Gets the permission_set_id of this BatchDeleteSecurityPermissionSetMembersRequest.

        权限集id

        :return: The permission_set_id of this BatchDeleteSecurityPermissionSetMembersRequest.
        :rtype: str
        """
        return self._permission_set_id

    @permission_set_id.setter
    def permission_set_id(self, permission_set_id):
        """Sets the permission_set_id of this BatchDeleteSecurityPermissionSetMembersRequest.

        权限集id

        :param permission_set_id: The permission_set_id of this BatchDeleteSecurityPermissionSetMembersRequest.
        :type permission_set_id: str
        """
        self._permission_set_id = permission_set_id

    @property
    def workspace(self):
        """Gets the workspace of this BatchDeleteSecurityPermissionSetMembersRequest.

        workspace 信息

        :return: The workspace of this BatchDeleteSecurityPermissionSetMembersRequest.
        :rtype: str
        """
        return self._workspace

    @workspace.setter
    def workspace(self, workspace):
        """Sets the workspace of this BatchDeleteSecurityPermissionSetMembersRequest.

        workspace 信息

        :param workspace: The workspace of this BatchDeleteSecurityPermissionSetMembersRequest.
        :type workspace: str
        """
        self._workspace = workspace

    @property
    def body(self):
        """Gets the body of this BatchDeleteSecurityPermissionSetMembersRequest.

        :return: The body of this BatchDeleteSecurityPermissionSetMembersRequest.
        :rtype: :class:`huaweicloudsdkdataartsstudio.v1.BatchDeleteBaseDTO`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this BatchDeleteSecurityPermissionSetMembersRequest.

        :param body: The body of this BatchDeleteSecurityPermissionSetMembersRequest.
        :type body: :class:`huaweicloudsdkdataartsstudio.v1.BatchDeleteBaseDTO`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchDeleteSecurityPermissionSetMembersRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdataartsstudio-3.1.125-py2.py3-none-any.whl: huaweicloudsdkdataartsstudio/v1/model/batch_delete_security_permission_set_members_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchDeleteSecurityPermissionSetMembersRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'permission_set_id': 'str',
        'workspace': 'str',
        'body': 'BatchDeleteBaseDTO'
    }

    attribute_map = {
        'permission_set_id': 'permission_set_id',
        'workspace': 'workspace',
        'body': 'body'
    }

    def __init__(self, permission_set_id=None, workspace=None, body=None):
        """BatchDeleteSecurityPermissionSetMembersRequest

        The model defined in huaweicloud sdk

        :param permission_set_id: 权限集id
        :type permission_set_id: str
        :param workspace: DataArts Studio工作空间ID
        :type workspace: str
        :param body: Body of the BatchDeleteSecurityPermissionSetMembersRequest
        :type body: :class:`huaweicloudsdkdataartsstudio.v1.BatchDeleteBaseDTO`
        """
        
        

        self._permission_set_id = None
        self._workspace = None
        self._body = None
        self.discriminator = None

        self.permission_set_id = permission_set_id
        self.workspace = workspace
        if body is not None:
            self.body = body

    @property
    def permission_set_id(self):
        """Gets the permission_set_id of this BatchDeleteSecurityPermissionSetMembersRequest.

        权限集id

        :return: The permission_set_id of this BatchDeleteSecurityPermissionSetMembersRequest.
        :rtype: str
        """
        return self._permission_set_id

    @permission_set_id.setter
    def permission_set_id(self, permission_set_id):
        """Sets the permission_set_id of this BatchDeleteSecurityPermissionSetMembersRequest.

        权限集id

        :param permission_set_id: The permission_set_id of this BatchDeleteSecurityPermissionSetMembersRequest.
        :type permission_set_id: str
        """
        self._permission_set_id = permission_set_id

    @property
    def workspace(self):
        """Gets the workspace of this BatchDeleteSecurityPermissionSetMembersRequest.

        DataArts Studio工作空间ID

        :return: The workspace of this BatchDeleteSecurityPermissionSetMembersRequest.
        :rtype: str
        """
        return self._workspace

    @workspace.setter
    def workspace(self, workspace):
        """Sets the workspace of this BatchDeleteSecurityPermissionSetMembersRequest.

        DataArts Studio工作空间ID

        :param workspace: The workspace of this BatchDeleteSecurityPermissionSetMembersRequest.
        :type workspace: str
        """
        self._workspace = workspace

    @property
    def body(self):
        """Gets the body of this BatchDeleteSecurityPermissionSetMembersRequest.

        :return: The body of this BatchDeleteSecurityPermissionSetMembersRequest.
        :rtype: :class:`huaweicloudsdkdataartsstudio.v1.BatchDeleteBaseDTO`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this BatchDeleteSecurityPermissionSetMembersRequest.

        :param body: The body of this BatchDeleteSecurityPermissionSetMembersRequest.
        :type body: :class:`huaweicloudsdkdataartsstudio.v1.BatchDeleteBaseDTO`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchDeleteSecurityPermissionSetMembersRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
